pub struct UsingStrict;
Encodes by running strict encoding procedure on the raw data without any pre-processing.

Should not be used for array types (require manual CommitEncode implementation involving merklization) or data which may contain confidential or sensitive information (use UsingConceal in this case).